@@ -1,11 +1,12 @@
 package Git::Repository::Log;
+{
+  $Git::Repository::Log::VERSION = '1.301';
+}
 
 use strict;
 use warnings;
 use 5.006;
 
-our $VERSION = '1.02';
-
 # a few simple accessors
 for my $attr (
     qw(
@@ -65,12 +66,20 @@ sub new {
 
 1;
 
+# ABSTRACT: Class representing git log data
+
+
 __END__
+=pod
 
 =head1 NAME
 
 Git::Repository::Log - Class representing git log data
 
+=head1 VERSION
+
+version 1.301
+
 =head1 SYNOPSIS
 
     # load the Log plugin
@@ -213,16 +222,14 @@ The unindented version of the log message.
 
 =head1 AUTHOR
 
-Philippe Bruhat (BooK), C<< <book at cpan.org> >>
+Philippe Bruhat (BooK) <book@cpan.org>
 
-=head1 COPYRIGHT
+=head1 COPYRIGHT AND LICENSE
 
-Copyright 2010 Philippe Bruhat (BooK), all rights reserved.
+This software is copyright (c) 2013 by Philippe Bruhat (BooK).
 
-=head1 LICENSE
-
-This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl itself.
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
